@@ -11,7 +11,7 @@ from collections import namedtuple
 import platform
 import shutil
 import warnings
-from .commons import twodec, twodecname, fourdec
+from .commons import twodec, twodecname, fourdec, pick_work_free_from_csv_line
 from .preparation import which
 from .settings import warning_dict, date_time
 
@@ -92,35 +92,6 @@ def matplotlib_bar(args, values="R-values", flag_sets=[], ready_shells=[]):
     errors_work_list = []
     errors_free_list = []
 
-    def pick_work_free_from_csv_line(line, values_work_list, values_free_list,
-                                     errors_work_list, errors_free_list,
-                                     errors=False):
-        if line.lstrip()[0] == "#":  # If it is a comment, do not load data
-            continue_sign = True
-            return values_work_list, values_free_list, errors_work_list, errors_free_list, continue_sign
-        continue_sign = False
-        try:
-            values_work_list.append(float(line.split()[3]))
-        except ValueError:
-            values_work_list.append(None)
-        try:
-            values_free_list.append(float(line.split()[6]))
-        except ValueError:
-            values_free_list.append(None)
-        if errors:  # return also standard error of mean
-            try:
-                errors_work_list.append(float(line.split()[9]))
-            except ValueError:
-                errors_work_list.append(float('nan'))            
-            try:
-                errors_free_list.append(float(line.split()[10]))
-            except ValueError:
-                errors_free_list.append(float('nan'))
-        else:
-            errors_work_list.append(float('nan'))
-            errors_free_list.append(float('nan'))
-        return values_work_list, values_free_list, errors_work_list, errors_free_list, continue_sign
-
     if flag_sets:
         # Chart for the complete cross-validation
         # (differences of statistics depending on to various FreeRflag sets)
@@ -417,14 +388,15 @@ def matplotlib_line(shells, project, statistics, n_bins_low, title, flag=0,
             values_list = []
             if statistic == "Rfree_cyc":
                 values_column = 2  # for refmac
-                values_range = (20, 26)  # for phenix
+                # values_range = (20, 26)  # for phenix
                 values_label = r'$\it{R}_\mathrm{free}$'
                 color = "#6AADE4"
             else:  # Rwork
                 values_column = 1  # for refmac
-                values_range = (13, 18)  # for phenix
+                # values_range = (13, 18)  # for phenix
                 values_label = r'$\it{R}_\mathrm{work}$'
                 color = "#0065BD"
+                
             prefix = project + "_R" + str(flag).zfill(2) + "_" + \
                     twodecname(shells[-1]) + "A"
             if refinement == "refmac":
@@ -457,11 +429,18 @@ def matplotlib_line(shells, project, statistics, n_bins_low, title, flag=0,
                                      "Statistics could not be found.\n"
                                      "Aborting.\n")
                     sys.exit(1)
+                offset = 0
+                while lines[j][offset] != ":":
+                    offset = offset + 1
+                if statistic == "Rwork_cyc":
+                    values_range = (offset + 2, offset + 8)
+                elif statistic == "Rfree_cyc":
+                    values_range = (offset + 9, offset + 15)
                 while lines[j].split()[-1][-1] != '-':  # until hline ---------
                     values_list.append(float(
                         lines[j][values_range[0]:values_range[1]]))
                     if not len(xticklabels_list) == len(xshell_list):
-                        xticklabel = lines[j][0:11]
+                        xticklabel = lines[j][:offset]
                         xticklabel.strip()
                         xticklabels_list.append(xticklabel)
                     j = j + 1
@@ -590,7 +569,8 @@ def matplotlib_line(shells, project, statistics, n_bins_low, title, flag=0,
 
 
 def write_log_html(shells, ready_shells, args, versions_dict, flag_sets,
-                   res_cur=0, ready_merging_statistics=False, done=False):
+                   res_cur=0, ready_merging_statistics=False, done=False,
+                   cutoff=[], accepted=[], reason=[]):
     """Created html output log.
 
     Args:
@@ -639,7 +619,7 @@ def write_log_html(shells, ready_shells, args, versions_dict, flag_sets,
     page += """</head>
 <body>
     <div id="header">
-        <div id="title">PAIREF</div>
+        <div id="title">PAIREF """ + versions_dict["pairef_version"] + """</div>
         <div id="subtitle">Automatic PAIRed REFinement protocol</div>
     </div>
 
@@ -663,6 +643,39 @@ def write_log_html(shells, ready_shells, args, versions_dict, flag_sets,
             """REFRESH</a></span>\n"""
         page += "\t</div>\n"
 
+    if cutoff:  # Assuming vars `accepted` and `reason` are also available
+        if done:
+            page += "\t<h2>VERDICT - suggested cutoff: "
+        else:
+            page += "\t<h2>Preliminary suggested cutoff: "
+        if cutoff[0] == cutoff[1]:
+            page += twodec(cutoff[0])
+        else:
+            page += "strict: " + twodec(cutoff[0]) + " A; benevolent: "  + twodec(cutoff[1])
+        page += " A</h2>\n"
+        page += "\t\t<table class='suggestion'>\n"
+        page += "\t\t<tr><th>Shell</th><th>Accepted?</th><th>Reason</th></tr>\n"
+        for i, shell in enumerate(ready_shells[1:]):
+            if not accepted[i][1] and not accepted[i][0]:
+                page += "\t\t<tr class='rejected'>\n"
+            elif "lowNfree" + twodec(shell) in warning_dict:
+                page += "\t\t<tr class='lowNfree'>\n"
+            elif accepted[i][1] and not accepted[i][0]:
+                page += "\t\t<tr class='benevolent'>\n"
+            else:  # elif accepted[i][0]:
+                page += "\t\t<tr class='accepted'>\n"
+            page += "\t\t\t<td>"
+            page += twodec(shells[i]) + "-" + twodec(shell) + " A</td>\n"
+            page += "\t\t\t<td>"
+            if accepted[i][0]:
+                page += "Yes"
+            elif accepted[i][1] and not accepted[i][0]:
+                page += "Warning"
+            else:
+                page += "No"
+            page += "</td>\n\t\t\t<td>"
+            page += "<br />\n".join(reversed(reason[i])) + "</td>\n\t\t</tr>\n"
+        page += "\t\t</table>\n"
     page += "\t<h2>Input parameters</h2>\n"
     page += "\t\t<table>\n"
     page += "\t\t<tr><td>Project:</td><td>" + args.project + "</td></tr>\n"
@@ -823,7 +836,7 @@ def write_log_html(shells, ready_shells, args, versions_dict, flag_sets,
 
         # "Rfree", "CCfree", "Rwork", "CCwork", "No_work_free_refl." graphs
         if not args.complete_cross_validation:
-            page += '\t<h2>Dependence on resolution</h2>\n'
+            page += '\t<h2>Model statistics - binned values</h2>\n'
             # Show relating warnings if there are some
             warning_keys = ["Nfree", "high_R", "low_R", "low_CC"]
             page = warning_orangebox(warning_keys, page)
